@@ -45,7 +45,7 @@ def fis_eda_categoric_graph(df_cat):
         ax[cada].set_title(variable, fontsize = 12, fontweight = "bold")
         ax[cada].tick_params(labelsize = 12)
         
-def fis_eda_continous_graph(df_cont):
+def fis_eda_continous_graph(df_cont,mode='density'):
     """
     Salida gráfica de todas las variables continuas para exploration data analysis
     """
@@ -61,7 +61,10 @@ def fis_eda_continous_graph(df_cont):
 
     #Creamos el bucle que va añadiendo gráficos
     for cada, variable in enumerate(df_cont):
-        df_cont[variable].plot.density(ax = ax[cada])
+        if mode=='density':
+            df_cont[variable].plot.density(ax = ax[cada])
+        else:
+            df_cont[variable].plot(ax = ax[cada])
         ax[cada].set_title(variable, fontsize = 12, fontweight = "bold")
         ax[cada].tick_params(labelsize = 12)
         
